@@ -19,7 +19,6 @@
 /* VTE accessibility object.  Based heavily on inspection of libzvt's
  * accessibility code. */
 
-#ident "$Id: vteaccess.c,v 1.47 2006/01/15 21:09:40 gpastore Exp $"
 
 #include "../config.h"
 
@@ -34,12 +33,7 @@
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
-
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#else
-#define bindtextdomain(package,dir)
-#endif
+#include <glib/gi18n-lib.h>
 
 #define VTE_TERMINAL_ACCESSIBLE_PRIVATE_DATA "VteTerminalAccessiblePrivateData"
 
@@ -69,7 +63,7 @@ static VteTerminalAccessiblePrivate *
 vte_terminal_accessible_new_private_data(void)
 {
 	VteTerminalAccessiblePrivate *priv;
-	priv = g_malloc0(sizeof(*priv));
+	priv = g_slice_new0(VteTerminalAccessiblePrivate);
 	priv->snapshot_text = NULL;
 	priv->snapshot_characters = NULL;
 	priv->snapshot_attributes = NULL;
@@ -101,7 +95,7 @@ vte_terminal_accessible_free_private_data(VteTerminalAccessiblePrivate *priv)
 		g_array_free(priv->snapshot_linebreaks, TRUE);
 		priv->snapshot_linebreaks = NULL;
 	}
-	g_free(priv);
+	g_slice_free(VteTerminalAccessiblePrivate, priv);
 }
 
 static gint
@@ -455,6 +449,7 @@ vte_terminal_accessible_text_modified(VteTerminal *terminal, gpointer data)
 	VteTerminalAccessiblePrivate *priv;
 	char *old, *current;
 	glong offset, olen, clen;
+	gint old_snapshot_caret;
 
 	g_assert(VTE_IS_TERMINAL_ACCESSIBLE(data));
 
@@ -462,6 +457,7 @@ vte_terminal_accessible_text_modified(VteTerminal *terminal, gpointer data)
 				 VTE_TERMINAL_ACCESSIBLE_PRIVATE_DATA);
 	g_assert(priv != NULL);
 
+	old_snapshot_caret = priv->snapshot_caret;
 	priv->snapshot_contents_invalid = TRUE;
 	vte_terminal_accessible_update_private_data_if_needed(ATK_OBJECT(data),
 							      &old, &olen);
@@ -479,6 +475,23 @@ vte_terminal_accessible_text_modified(VteTerminal *terminal, gpointer data)
 		offset++;
 	}
 
+        /* Check if we just backspaced over a space. */
+	if ((olen == offset) && (old[priv->snapshot_caret] == ' ') &&
+	    (old_snapshot_caret == (priv->snapshot_caret + 1))) {
+		glong bsp_olen = priv->snapshot_caret+1;
+                glong bsp_offset = priv->snapshot_caret;
+
+                priv->snapshot_text->str = old;
+		priv->snapshot_text->len = bsp_olen;
+		emit_text_changed_delete(G_OBJECT(data),
+					 old,
+					 bsp_offset,
+					 bsp_olen - bsp_offset);
+		priv->snapshot_text->str = current;
+		priv->snapshot_text->len = clen;
+	}
+
+
 	/* At least one of them had better have more data, right? */
 	if ((offset < olen) || (offset < clen)) {
 		/* Back up from both end points until we find the *last* point
@@ -497,10 +510,17 @@ vte_terminal_accessible_text_modified(VteTerminal *terminal, gpointer data)
 		/* Now emit a deleted signal for text that was in the old
 		 * string but isn't in the new one... */
 		if (olen > offset) {
+			gchar *saved_str = priv->snapshot_text->str;
+			gsize saved_len = priv->snapshot_text->len;
+
+			priv->snapshot_text->str = old;
+			priv->snapshot_text->len = olen;
 			emit_text_changed_delete(G_OBJECT(data),
 						 old,
 						 offset,
 						 olen - offset);
+			priv->snapshot_text->str = saved_str;
+			priv->snapshot_text->len = saved_len;
 		}
 		/* .. and an inserted signal for text that wasn't in the old
 		 * string but is in the new one. */
